@@ -7,20 +7,23 @@ from rich.tree import Tree
 from rich.json import JSON
 from rich.markdown import Markdown
 from audiodotturn.config import Config
+from audiodotturn.errors import error_handler
+
 
 class Create(Config):
     """
     Class that provides functionality for creating formatted files, directories and JSON data.
     """
+
     def __init__(self, args: argparse.Namespace):
         """
         Initialize the Create class object.
 
         Args:
-        - args: An argparse.Namespace object containing the command line arguments passed to the Create class object.
+            args: An argparse.Namespace object containing the command line arguments passed to the Create class object.
 
         Returns:
-        - None
+            None
         """
         self.args = args
         # grab defaults
@@ -30,6 +33,7 @@ class Create(Config):
         self.filename = self.args.filename
         self.directory = self.args.directory
         self.formatter = self.args.formatter.lower().strip()
+        self.msg = None
 
     # create runner
     def run(self) -> None:
@@ -37,10 +41,10 @@ class Create(Config):
         Run the Create class.
 
         Args:
-        - None
+            None
 
         Returns:
-        - None
+            None
         """
         with self.console.status("[bold green]Working..."):
             if self.args.dirs:
@@ -51,7 +55,7 @@ class Create(Config):
             elif self.args.formatdir:
                 self.msg = self.format_files_dir()
             elif self.args.dump:
-                tree = Tree('DUMP')
+                tree = Tree("DUMP")
                 dump = self.json_dump()
                 if type(dump) is tuple:
                     tree.add("[green]Runtime Info").add(JSON(dump[0]), highlight=True)
@@ -64,15 +68,17 @@ class Create(Config):
 
     # check whether a file is formatted, unable to be formatted, or
     # unchanged due to already being formatted or an incompatible extension
-    def form_or_not(self, files_list: list) -> tuple[list[str], list[str], list[str], list[str]]:
+    def form_or_not(
+        self, files_list: list
+    ) -> tuple[list[str], list[str], list[str], list[str]]:
         """
         Check whether a file is formatted, unable to be formatted, or unchanged due to already being formatted or an incompatible extension.
 
         Args:
-        - files_list: A list of filenames.
+            files_list: A list of filenames.
 
         Returns:
-        - A tuple containing four lists: the formatted files, the unformatted files, the already formatted files, and the statistics of the number of each type of file.
+            tuple: A tuple containing four lists: the formatted files, the unformatted files, the already formatted files, and the statistics of the number of each type of file.
         """
         formatted = ["\n## Formatted:"]
         not_formatted = ["\n## Not Formatted:"]
@@ -98,10 +104,10 @@ class Create(Config):
         Create directories based off of unique artists in music library.
 
         Args:
-        - None
+            None
 
         Returns:
-        - A string message about the directories created and the number of files that were organized.
+            str: A string message about the directories created and the number of files that were organized.
         """
         directory = self.directory.rstrip("/")
         artists, files = set(), set()
@@ -132,9 +138,10 @@ class Create(Config):
                         shutil.move(
                             f"{self.directory}/{filename}", f"{artist_dir}/{filename}"
                         )
-                    except:
-                        self.console.log(f"{self.directory}/{filename} unsuccesful move to {artist_dir}/{filename}")
-                        pass
+                    except FileExistsError:
+                        self.console.log(
+                            f"{self.directory}/{filename} unsuccesful move to {artist_dir}/{filename}"
+                        )
         return (
             f"### Organized {len(files)} files for {len(artists)} artists.\n"
             + "#### Created directories:\n"
@@ -148,7 +155,7 @@ class Create(Config):
         summarizing the results of the formatting.
 
         Returns:
-        - A string summarizing the results of the formatting.
+            str: A string summarizing the results of the formatting.
         """
         directory = self.directory.rstrip("/")
         try:
@@ -163,8 +170,8 @@ class Create(Config):
                 files_list
             )
             return "\n".join(formatted + not_formatted + already_formatted + stats)
-        except Exception as error:
-            return f"{error}"
+        except (TypeError, FileNotFoundError) as error:
+            error_handler(self.error_msg, self.console, error)
 
     # file argument really only used by format_files_dir, otherwise will use self.filename
     def format_file(self, file: str = None) -> str:
@@ -172,10 +179,10 @@ class Create(Config):
         Formats a single file name according to the formatter specified in the class.
 
         Args:
-        - file: A string representing the name of the file to be formatted. If None, uses the filename specified in the class.
+            file: A string representing the name of the file to be formatted. If None, uses the filename specified in the class.
 
         Returns:
-        - A string representing the formatted file name.
+            str: A string representing the formatted file name.
         """
         # get filename and create a temp filename
         if file:
@@ -197,12 +204,12 @@ class Create(Config):
 
     def json_dump(self) -> str | tuple[str, str]:
         """
-        Finds all properly formatted files in the directory specified in the class and writes the resulting data to a JSON file. 
-        If dry-run is enabled, does not actually write the file, but instead returns a string representation of the data that 
+        Finds all properly formatted files in the directory specified in the class and writes the resulting data to a JSON file.
+        If dry-run is enabled, does not actually write the file, but instead returns a string representation of the data that
         would have been written to the file. Returns a tuple of two strings in this case.
 
         Returns:
-        - A string summarizing the result of the JSON dump. If dry-run is enabled, returns a tuple of two strings instead.
+            str: A string summarizing the result of the JSON dump. If dry-run is enabled, returns a tuple of two strings instead.
         """
         # check if valid directory
         if not os.path.isdir(self.directory):
@@ -213,6 +220,7 @@ class Create(Config):
                         "Status": "FAILED",
                         "Final": f"Data has FAILED to be dumped into {self.filename}.",
                         "Reason": f"Directory path '{self.directory}' not found.",
+                        "Possible solution": "Ensure the directory exists and its path is correct."
                     }
                 }
             )
@@ -269,6 +277,7 @@ class Create(Config):
                         "Status": "FAILED",
                         "Final": f"Data has FAILED to be dumped into {self.filename}.",
                         "Reason": "No data available. Most likely cause is having no formatted files available in directory.",
+                        "Possible solutions": "Check and make sure you have properly formatted filenames, audiodotturn will ignore unformatted files during the data dump."
                     }
                 }
             )
@@ -276,7 +285,7 @@ class Create(Config):
         # if not a dry run then create the json dump in the given location
         # otherwise just print it
         if not self.dry:
-            with open(os.path.join(self.filename), "w", encoding='utf-8') as f:
+            with open(os.path.join(self.filename), "w", encoding="utf-8") as f:
                 json.dump(data, f, indent=2)
             return json.dumps(
                 {
@@ -308,12 +317,12 @@ class Create(Config):
 
         The method checks for existing data in the filename and fills in missing data with defaults
         specified in the configuration file.
-        
+
         Args:
-        - file (str): The name of the file to be formatted.
-        
+            file (str): The name of the file to be formatted.
+
         Returns:
-        - str: The formatted filename string.
+            str: The formatted filename string.
         """
         # check if already formatted or if not an audio file, if so add $$ to temp name
         format_check = re.search(
@@ -371,23 +380,15 @@ class Create(Config):
             if any(features):
                 self.features = []
                 if features_1:
-                    self.features.append(
-                        features_1.group(1).strip()
-                    )
-                
+                    self.features.append(features_1.group(1).strip())
+
                 if features_2:
-                    self.features.append(
-                        features_2.group(2).strip()
-                    ) 
+                    self.features.append(features_2.group(2).strip())
                 if features_3:
-                    self.features.append(
-                        features_3.group(1).strip()
-                    ) 
+                    self.features.append(features_3.group(1).strip())
 
                 if features_4:
-                    self.features.append(
-                        features_4.group(2).strip()
-                    )
+                    self.features.append(features_4.group(2).strip())
 
                 self.features = ", ".join(self.features).replace("'", "")
 
@@ -439,12 +440,12 @@ class Create(Config):
 
         The method checks for existing data in the filename and fills in missing data with defaults
         specified in the configuration file.
-        
+
         Args:
-        - file (str): The name of the file to be formatted.
-        
+            file (str): The name of the file to be formatted.
+
         Returns:
-        - str: The formatted filename string.
+            str: The formatted filename string.
         """
         # check if already formatted or if not an audio file, if so add $$ to temp name
         format_check = re.search(r"\[(.+?)\]\[(.+?)\]\[(.+?)\]\[(.+?)\]\.(.+?)$", file)
@@ -502,23 +503,15 @@ class Create(Config):
             if any(features):
                 self.features = []
                 if features_1:
-                    self.features.append(
-                        features_1.group(1).strip()
-                    )
-                
+                    self.features.append(features_1.group(1).strip())
+
                 if features_2:
-                    self.features.append(
-                        features_2.group(2).strip()
-                    ) 
+                    self.features.append(features_2.group(2).strip())
                 if features_3:
-                    self.features.append(
-                        features_3.group(1).strip()
-                    ) 
+                    self.features.append(features_3.group(1).strip())
 
                 if features_4:
-                    self.features.append(
-                        features_4.group(2).strip()
-                    )
+                    self.features.append(features_4.group(2).strip())
 
                 self.features = ", ".join(self.features).replace("'", "")
 
